@@ -61,6 +61,9 @@ def parse(html: str, p: Product, include: Sequence = None):
     def should_variation():
         return "variation_values" in include or "selected_variations" in include or "asin_variation_values" in include
 
+    def should_thumbnail():
+        return "thumbnail" in include or "thumbnails" in include
+
     sel = parsel.Selector(text=html)
     "parent_asin" in include and parse_parent_asin(p, selector=sel)
     "weight" in include and parse_weight(p, selector=sel)
@@ -83,7 +86,7 @@ def parse(html: str, p: Product, include: Sequence = None):
     "review_amount" in include and parse_review_amount(p, selector=sel)
     "review_star" in include and parse_review_star(p, selector=sel)
     "rank" in include and parse_rank(p, selector=sel)
-    "thumbnail" in include and parse_thumbnail(p, selector=sel)
+    should_thumbnail() and parse_thumbnail(p, selector=sel)
     "category" in include and parse_category(p, selector=sel)
     "currency" in include and parse_currency(p, selector=sel)
     "date_first_avail" in include and parse_date_first_avail(p, selector=sel)
